@@ -92,8 +92,8 @@ define([
             this.chartTypeList = {
                 'Relational': [ 'scatterplot', 'lineplot' ],
                 'Distributions': [ 'histplot', 'kdeplot', 'rugplot' ], 
-                'Categorical': [ 'stripplot', 'swarmplot', 'boxplot', 'violinplot', 'pointplot', 'barplot' ],
-                'ETC': [ 'countplot' ]
+                'Categorical': [ 'stripplot', 'swarmplot', 'boxplot', 'violinplot', 'pointplot', 'barplot', 'countplot' ],
+                'Axes-level': [ 'heatmap' ],
             }
 
             this.legendPosList = [
@@ -217,6 +217,8 @@ define([
                             $(that.wrapSelector('#sortHue')).closest('.sb-option').show();
                         }
                     }
+                } else if (chartType == 'heatmap') {
+                    $(that.wrapSelector('#annot')).closest('.sb-option').show();
                 }
             });
             
@@ -545,6 +547,8 @@ define([
                         $(page).find('#sortHue').closest('.sb-option').show();
                     }
                 }
+            } else if (this.state.chartType == 'heatmap') {
+                $(page).find('#annot').closest('.sb-option').show();
             }
 
             //================================================================
@@ -926,7 +930,8 @@ define([
                 etcOptionCode.push(com_util.formatString("marker='{0}'", markerStyle));
             }
             if (showValues === true && chartType === 'barplot') {
-                etcOptionCode.push('ci=None');
+                // etcOptionCode.push('ci=None'); // changed to errorbar after 0.12 version
+                etcOptionCode.push('errorbar=None');
             }
             if (setXY === false && sortType !== '') {
                 let sortCode = '';
@@ -939,10 +944,10 @@ define([
                 }
                 if (chartType === 'barplot' && sortX !== '' && sortY !== '') {
                     if (hue !== '' && sortHue !== '') {
-                        sortCode = com_util.formatString("{0}[{1}[{2}]=={3}].groupby({4})[{5}].mean().sort_values({6}).index"
+                        sortCode = com_util.formatString("{0}[{1}[{2}]=={3}].groupby({4})[{5}].mean(numeric_only=True).sort_values({6}).index"
                                             , state.data, state.data, state.hue, com_util.convertToStr(sortHue, sortHueText), sortX, sortY, sortTypeStr);
                     } else {
-                        sortCode = com_util.formatString("{0}.groupby({1})[{2}].mean().sort_values({3}).index", state.data, sortX, sortY, sortTypeStr);
+                        sortCode = com_util.formatString("{0}.groupby({1})[{2}].mean(numeric_only=True).sort_values({3}).index", state.data, sortX, sortY, sortTypeStr);
                     }
                 } else if (chartType === 'countplot' && (sortX !== '' || sortY !== '')) {
                     let countVar = sortX === ''? sortY: sortX;
